@@ -1,8 +1,7 @@
 #include "charclass.ih"
 
-CharClass &CharClass::concatenate(CharClass &left, CharClass const &right)
+CharClass &CharClass::concatenate(CharClass const &right)
 {
-    Vector &lhs = left.d_chars;
     Vector const &rhs = right.d_chars;
 
 //    cout << "CONCAT: left = ";
@@ -10,16 +9,14 @@ CharClass &CharClass::concatenate(CharClass &left, CharClass const &right)
 //    cout << "right = ";
 //    display(rhs);
 
-    copy(rhs.begin(), rhs.end(), back_inserter(lhs));
+    copy(rhs.begin(), rhs.end(), back_inserter(d_chars));
 
 //    cout << "out = ";
 //    display(lhs);
 //    cout << downCast<CharClass>(*left).str() << '\n';
 //    cout << "CONCAT OUT\n";
 
-//    lhs += rhs;
-
-    return left;    
+    return *this;
 }
 
 
