@@ -2,11 +2,14 @@
 
 bool DFA::setInitTailCount(TailCount::Type type, TailCount &thisTailCount)
 {
-    if (type & TailCount::PROCESSED)         // already handled this entry
-        return false;
+//    if (type & TailCount::PROCESSED)         // already handled this entry
+//        return false;
 
     thisTailCount.setTailCount(0);
-    thisTailCount.addFlag(TailCount::PROCESSED | TailCount::COUNT);
+
+//    thisTailCount.addFlag(TailCount::PROCESSED | TailCount::COUNT);
+    thisTailCount.addFlag(TailCount::COUNT);
+
     d_sawACCEPT = true;
 
 //cout << "From " << fmRow << ": initialized TailCount for row " << 
