@@ -17,9 +17,12 @@
     
 void DFA::visitTailCount(TailCount &tailCount)
 {
-    d_sawACCEPT = false;
+//    d_sawACCEPT = false;
     d_rule = tailCount.rule();
 
+                            // (re)initialize for this rule
+    d_transitSet = vector<Size_tSet>(d_row.size()); 
+
                             // this/previous row, ptr to previous TailCount 
     determineTailCount(tailCount, 0, 0, 0);
 }
