@@ -7,12 +7,12 @@ namespace
         // options to set filenames
 
         // options setting filenames
-        {Options::baseclassHeader(),        'b'},
-        {Options::classHeader(),            'c'},
-        {Options::implementationHeader(),   'i'},
-        {Options::lexSource(),              'l'},
-        {"target-directory",            Arg::Required},
-        {"filenames", 'f'},
+        {Options::baseclassHeaderSpec(),      'b'}, // Options members also
+        {Options::classHeaderSpec(),          'c'}, // used by Options::
+        {Options::implementationHeaderSpec(), 'i'}, // setAccessorVariables()
+        {Options::lexSourceSpec(),            'l'},
+        {"target-directory",                  Arg::Required},
+        {"filenames",                         'f'},
                                         
         // skeleton options             
         {"skeleton-directory",          'S'},
@@ -21,18 +21,16 @@ namespace
         {"implementation-skeleton",     'I'},
         {"lex-skeleton",                'L'},
 
-        // options forcing overwriting
-        {"force-class-header",          Arg::None},
-        {"force-implementation-header", Arg::None},
+        // options preventing overwriting
         {"no-baseclass-header",         Arg::None},
         {"no-lex-source",               Arg::None},
 
+        {"namespace",                   'n'},
+
         {"class-name",                  Arg::Required},
         {"lex-function-name",           Arg::Required},
         {"no-lines",                    Arg::None},
 
-        {"namespace",                   'n'},
-
         {"help",                        'h'},
         {"usage",                       'h'},
         {"version",                     'v'},
@@ -60,7 +58,7 @@ try
                     longOptions, longEnd, argc, argv);
     arg.versionHelp(usage, version, 1);
 
-    Options::init(arg);
+    DFA::setVerbose(arg.option('V'));
 
     States states;
 
@@ -69,12 +67,7 @@ try
 
     Parser parser(rules, states);
         parser.parse();
-
-    if (int count = emsg.count())
-    {
-        cout << "Error(s): " << count << '\n';
-        return 1;
-    }
+        parser.cleanup();
 
     Ranges ranges(states);
         ranges.determineSubsets();
@@ -91,7 +84,6 @@ try
         generator.baseclassHeader();
         generator.classHeader();
         generator.implementationHeader();
-        generator.showFilenames();
 }
 catch (int x)
 {
