@@ -10,10 +10,10 @@ void Generator::dfaRFCs(DFARow const &row, ostream &out,
     for (auto &tailCount: row.tailCounts())
         storeRFC(tailCount, final, rfc);
 
-    if (final.first != UINT_MAX)
+    if (final.first != numeric_limits<size_t>::max())
         rfc.push_back(RuleFlagCount {final.first, FINAL | BOL, 0});
 
-    if (final.second != UINT_MAX)
+    if (final.second != numeric_limits<size_t>::max())
         rfc.push_back(RuleFlagCount {final.second, FINAL, 0});
 
     out << setw(2) << rfc.size();               // end index in s_rfc__
