@@ -11,19 +11,21 @@
 
 void Generator::implementationHeader() const
 {
-    if 
-    (
-        Stat(d_options.implementationHeaderPath())
-        &&
-        not d_options("force-implementation-header")
-    )
+    string const &implementationHeader = d_options.implementationHeaderPath();
+
+    if (Stat(implementationHeader))
+    {
+        warnExisting(implementationHeader, d_options.classHeaderSpec(), 
+                        d_options.classHeaderName(),
+                        "^#include \"" + d_options.classHeaderName() + '"');
         return;
+    }
 
     ofstream out;
     ifstream in;
 
     Exception::open(in,  d_options.implementationSkeleton()); 
-    Exception::open(out, d_options.implementationHeaderPath()); 
+    Exception::open(out, implementationHeader); 
 
     filter(in, out);    
 }
