@@ -3,5 +3,5 @@
 void Generator::tailCount(ostream &out) const
 {
     out <<
-    "    d_tailCount(" << d_rules.size() << ", UINT_MAX),\n";
+    "    d_tailCount(" << d_rules.size() << ", std::numeric_limits<size_t>::max()),\n";
 }
