@@ -2,7 +2,6 @@
 #define INCLUDED_INTERVAL_
 
 #include <string>
-#include "../utility/utility.h"
 
 class Interval: private std::pair<size_t, size_t>
 {
@@ -10,6 +9,8 @@ class Interval: private std::pair<size_t, size_t>
     size_t d_upper;
 
     public:
+        Interval() = default;
+
         static Interval exact(std::string const &str);
         static Interval range(std::string const &lower, 
                               std::string const &upper);
@@ -20,22 +21,8 @@ class Interval: private std::pair<size_t, size_t>
 
     private:
         Interval(size_t lower, size_t upper);        
-
 };
 
-template <>                                     // two specializations:
-struct Type<Interval>                         // defining 'DataType'
-{                                               // given Interval
-    enum { dataType = DataType::INTERVAL };
-};
-
-template <>                                     // defining 'Interval'
-struct Type<Int<DataType::INTERVAL>>          // given INTERVAL
-{
-    typedef Interval type;
-};
-
-  
 inline Interval::Interval(size_t lower, size_t upper)
 :
     d_lower(lower),
