@@ -1,5 +1,7 @@
 #include "options.ih"
 
+// called by the generator, possibly overruling directives by options
+
 void Options::setAccessorVariables()
 {
     Arg &arg = Arg::instance();
@@ -11,20 +13,24 @@ void Options::setAccessorVariables()
 
     d_print = d_print || arg.option('t');
 
+    if (d_arg.option(&d_className, "class-name"))
+        s_warnOptions.insert("class-name");
+
     if (d_className.empty())
         d_className = s_defaultClassName;
 
     if (d_lexFunctionName.empty())
         d_lexFunctionName = s_defaultLexFunctionName;
 
-    arg.option(&d_nameSpace, 'n');  // -n overrules %namespace spec in lexer
-
     string value;
     d_maxDepth = arg.option(&value, 'm') ? 
-                    A2x(value).to<size_t>() 
+                    stoul(value)
                 : 
                     MAX_DEPTH;
-        
+
+    if (arg.option(&d_nameSpace, 'n'))
+        s_warnOptions.insert("namespace");
+
     // Skeletons
     if (!arg.option(&d_skeletonDirectory, 'S') && d_skeletonDirectory.empty())
         d_skeletonDirectory = s_defaultSkeletonDirectory;
@@ -48,25 +54,8 @@ void Options::setAccessorVariables()
     if (d_targetDirectory.length() && *d_targetDirectory.rbegin() != '/')
         d_targetDirectory += '/';
 
-    arg.option(&d_filenames, 'f');  // -f overrules %filenames spec in lexer
-
-    string filenames = d_filenames;
-    if (filenames.empty())
-        filenames = d_className;
-
     if (d_arg.option('K'))
         d_constructionPath = d_targetDirectory + d_arg[0] + ".output";
-
-    setPath(&d_classHeaderPath, 'c', filenames, ".h", classHeader());
-
-    setPath(&d_baseClassHeaderPath, 'b', filenames, "base.h", 
-            baseclassHeader());
-
-    setPath(&d_implementationHeaderPath, 'i', filenames, ".ih",
-                                                    implementationHeader());
-
-    setPath(&d_lexSourcePath, 'l', String::lc(d_lexFunctionName), ".cc",
-                                                    lexSource());
 }
 
 
