@@ -1,9 +1,12 @@
 #include "options.ih"
 
-void Options::setClassName(string const &name)
+void Options::setClassName()
 {
     if (d_className.size())
         emsg << "%class-name multiply specified" << endl;
     else
-        d_className = undelimit(name);
+        d_className = undelimit(*d_matched);
+
+    s_warnOptions.insert("class-name");
 }
+
