@@ -1,9 +1,9 @@
 #include "options.ih"
 
-void Options::setFilenames(string const &name)
+void Options::setFilenames()
 {
     if (d_filenames.size())
         emsg << "%filenames multiply specified" << endl;
     else
-        d_filenames = undelimit(name);
+        d_filenames = undelimit(*d_matched);
 }
