@@ -1,9 +1,9 @@
 #include "options.ih"
 
-void Options::setLexFunctionName(string const &name)
+void Options::setLexFunctionName()
 {
     if (d_lexFunctionName.size())
         emsg << "%lex-function-name multiply specified" << endl;
     else
-        d_lexFunctionName = undelimit(name);
+        d_lexFunctionName = undelimit(*d_matched);
 }
